package main

import (
	"database/sql"
	"intimate"
	"log"
	"testing"
	"time"

	"github.com/474420502/extractor"
	"github.com/tebeka/selenium"
)

func TestMain(t *testing.T) {
	Execute()
}

type LiveInfo struct {
	Followers int64   `exp:"//div[contains(@class,'nimo-rm_followers')]//span[@class='text c2']" mth:"r:ExtractNumber"`
	Views     int64   `exp:"//div[contains(@class,'nimo-rm_audience')]//span[@class='text c2']" mth:"r:ExtractNumber"`
	Channel   string  `exp:"//div[contains(@class,'nimo-rm_type')]//span"`
	Gratuity  []int64 `exp:"//div[contains(@class,'rank-item-after3')]//span[contains(@class,'nimo-currency__count')]"`
}

func Execute() {
	wd := intimate.GetChromeDriver(3031)
	waitfor := intimate.NewWaitFor(wd)
	ps := intimate.NewPerfectShutdown()

	for !ps.IsClose() {
		streamer, err := estore.Pop(intimate.PNimo)
		if err != nil {
			log.Println(err)
			estore.UpdateError(streamer, err)
			continue
		}

		wd.Get(streamer.LiveUrl.String)
		// wd.Get("https://www.nimo.tv/live/1253835677")

		waitfor.Default("//div[contains(@class,'nimo-rm_followers')]//span[@class='text c2' and text() != '']", nil)
		waitfor.WaitWithTimeout("//div[contains(@class,'rank-item-top3')]", 7*time.Second, nil)
		element, err := wd.FindElement(selenium.ByXPATH, "//div[contains(@class,'rank-item-top3')]")
		if err != nil {
			log.Println(streamer.Uid, err)
		} else {
			err = element.MoveTo(50, 50)
			element.Click()
			if err != nil {
				log.Println(streamer.Uid, err)
			}
		}
		waitfor.Default("//div[contains(@class,'nimo-rm_audience')]//span[@class='text c2']", nil)

		var pagesource string
		pagesource, _ = wd.PageSource()

		etor := extractor.ExtractHtmlString(pagesource)
		li := etor.GetObjectByTag(LiveInfo{}).(*LiveInfo)
		// log.Printf("%#v", li)

		utime := sql.NullTime{Time: time.Now(), Valid: true}

		clog := &intimate.CollectLog{}
		clog.Platform = intimate.PNimo
		clog.Followers = sql.NullInt64{Int64: li.Followers, Valid: true}
		clog.Views = sql.NullInt64{Int64: li.Views, Valid: true}
		clog.UpdateTime = utime
		clog.StreamerUid = streamer.Uid

		var sum int64 = 0
		for _, v := range li.Gratuity {
			sum += v
		}
		clog.Gratuity = sql.NullInt64{Int64: sum, Valid: true}

		cuid := estore.InsertClog(clog)

		streamer.Channel = sql.NullString{String: li.Channel, Valid: true}
		streamer.LatestLogUid = cuid
		streamer.UpdateTime = utime
		streamer.Operator = 0

		estore.Update(streamer, "channel", streamer.Channel, "latest_log_uid", streamer.LatestLogUid, "update_time", streamer.UpdateTime)
	}
}
